"""Registry keyset REST API views."""
from asgiref.sync import sync_to_async
from ninja import Router
from regal import KeysetId

from ferda.api import Error, check_permissions
from ferda.backend import STATEMENTOR
from ferda.constants import LogReferenceType
from ferda.registry.record_statement import get_object_statement_pdf

from .search import router as search_router

router = Router(tags=['registry', 'keyset'])
router.add_router('search', search_router)


@router.get('/record_statement/{keyset_id}/', url_name='get_keyset_record_statement_pdf', response={
    200: bytes,
    404: Error,
})
async def get_keyset_record_statement_pdf(request, keyset_id: KeysetId):
    """Get verified record statement of the keyset."""
    await sync_to_async(check_permissions)(request, permissions=['ferda.can_view_registry'])
    return await get_object_statement_pdf(
        request, KeysetId(keyset_id), LogReferenceType.KEYSET, STATEMENTOR.get_keyset_statement
    )
